import greenfoot.*;

/**
 * This class displays a choice and waits for the user to select one; then informs the calling world of that choice.
 */
public class Select extends Terminal
{
    public static boolean authorized;
    private Main main; // to hold a reference to the calling world
    private Options options = new Options();
    private int setNumber;

    /**
     * This constructor displays the instructions in the background of this terminal object
     * after saving a reference to the calling world.
     *
     * @param world: the world that created this Option object
     */
    public Select(Main world)
    {
        super(Color.CYAN, Color.BLACK);
        main = world; // saves a reference to the calling world
    }
    
    public void runOption(int setIndex)
    {
        if (setIndex < 0 || setIndex >= options.getSetCount()) return;
        setNumber = setIndex;
        if (!authorized)
        {
            new Pass("password", "Option selecting is restricted\nto authorized persons only.", this, main);
            return;
        }
        displayOptionSet();
    }
    
    private void displayOptionSet()
    {
        Greenfoot.setWorld(this); // self-activates this world
        printLine(options.getPrompt(setNumber)+":");
        String[] opts = options.getOptions(setNumber);
        String keys = options.getOptionKeys(setNumber);
        for (int i=0; i<opts.length; i++) printLine("     Press  '"+keys.charAt(i)+"'  for "+opts[i]);
    }

    /**
     * Checks for valid keystroke and informs the calling world of the choice made.
     */
    public void act()
    {
        if (!authorized)
        {
            authorized = true;
            displayOptionSet();
        }
        String key = Greenfoot.getKey();
        if (key == null) return;
        int choice = options.getOptionKeys(setNumber).indexOf(key);
        if (choice >= 0 || "escape".equals(key))
        {
            printLine(key);
            printLine("");
            main.setOption(choice);
        }
    }
    
    public static boolean isAuthorized()
    {
        return authorized;
    }
}