import greenfoot.*;

public class Terminal extends World
{
    public Color bgColor = Color.WHITE, txtColor = Color.BLACK;
    private int lineCount; // tracks the number of lines printed to the 'terminal'
    
    /**
     * This constructor passes the dimensions of the new world to the World class to create the world.
     */
    public Terminal()
    {
        this(Color.WHITE, Color.BLACK);
    }
    
    public Terminal(Color bgKolor, Color txtKolor)
    {
        super(600, 400, 1);
        bgColor = new Color(bgKolor.getRed(), bgKolor.getGreen(), bgKolor.getBlue());
        clearScreen();
        txtColor = txtKolor;
    }

    /**
     * This method prints the given line to the terminal and performs a line-feed if last line on screen.
     *
     * @param line: the line to print to the terminal
     */
    protected void printLine(String line)
    {
        lineCount++;
        getBackground().setColor(txtColor);
        getBackground().drawString(line, 5, lineCount*16);
        if (lineCount == 25)
        {
            lineCount--;
            lineFeed();
        }
        Greenfoot.delay(5);
    }
    
    /**
     * This method moves all data up one line position removing the top-most line.
     */
    protected void lineFeed()
    {
        GreenfootImage img = new GreenfootImage(getBackground());
        GreenfootImage bg = getBackground();
        bg.setColor(bgColor);
        bg.fill();
        bg.drawImage(img, 0, -16);
    }
    
    /**
     * This method clears the terminal of all characters and sets the top-most line as the new print-line.
     */
    protected void clearScreen()
    {
        GreenfootImage bg = getBackground();
        bg.setColor(bgColor);
        bg.fill();
        lineCount = 0;
    }        
}